@@ -1,7 +1,7 @@
 #! /bin/false
 # vim: set autoindent shiftwidth=4 tabstop=4:
 
-# Conversion routines for ISO-8859-9.
+# Conversion routines for ISO-8859-7.
 # Copyright (C) 2002-2016 Guido Flohr <guido.flohr@cantanea.com>,
 # all rights reserved.
 
@@ -18,7 +18,7 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-package Locale::RecodeData::ISO_8859_9;
+package Locale::RecodeData::ISO_8859_7;
 
 use strict;
 
@@ -187,101 +187,101 @@ my @to_ucs4 = (
     0x009e,
     0x009f,
     0x00a0,
-    0x00a1,
-    0x00a2,
+    0x2018,
+    0x2019,
     0x00a3,
-    0x00a4,
-    0x00a5,
+    0xfffd,
+    0xfffd,
     0x00a6,
     0x00a7,
     0x00a8,
     0x00a9,
-    0x00aa,
+    0xfffd,
     0x00ab,
     0x00ac,
     0x00ad,
-    0x00ae,
-    0x00af,
+    0xfffd,
+    0x2015,
     0x00b0,
     0x00b1,
     0x00b2,
     0x00b3,
-    0x00b4,
-    0x00b5,
-    0x00b6,
+    0x0384,
+    0x0385,
+    0x0386,
     0x00b7,
-    0x00b8,
-    0x00b9,
-    0x00ba,
+    0x0388,
+    0x0389,
+    0x038a,
     0x00bb,
-    0x00bc,
+    0x038c,
     0x00bd,
-    0x00be,
-    0x00bf,
-    0x00c0,
-    0x00c1,
-    0x00c2,
-    0x00c3,
-    0x00c4,
-    0x00c5,
-    0x00c6,
-    0x00c7,
-    0x00c8,
-    0x00c9,
-    0x00ca,
-    0x00cb,
-    0x00cc,
-    0x00cd,
-    0x00ce,
-    0x00cf,
-    0x011e,
-    0x00d1,
-    0x00d2,
-    0x00d3,
-    0x00d4,
-    0x00d5,
-    0x00d6,
-    0x00d7,
-    0x00d8,
-    0x00d9,
-    0x00da,
-    0x00db,
-    0x00dc,
-    0x0130,
-    0x015e,
-    0x00df,
-    0x00e0,
-    0x00e1,
-    0x00e2,
-    0x00e3,
-    0x00e4,
-    0x00e5,
-    0x00e6,
-    0x00e7,
-    0x00e8,
-    0x00e9,
-    0x00ea,
-    0x00eb,
-    0x00ec,
-    0x00ed,
-    0x00ee,
-    0x00ef,
-    0x011f,
-    0x00f1,
-    0x00f2,
-    0x00f3,
-    0x00f4,
-    0x00f5,
-    0x00f6,
-    0x00f7,
-    0x00f8,
-    0x00f9,
-    0x00fa,
-    0x00fb,
-    0x00fc,
-    0x0131,
-    0x015f,
-    0x00ff,
+    0x038e,
+    0x038f,
+    0x0390,
+    0x0391,
+    0x0392,
+    0x0393,
+    0x0394,
+    0x0395,
+    0x0396,
+    0x0397,
+    0x0398,
+    0x0399,
+    0x039a,
+    0x039b,
+    0x039c,
+    0x039d,
+    0x039e,
+    0x039f,
+    0x03a0,
+    0x03a1,
+    0xfffd,
+    0x03a3,
+    0x03a4,
+    0x03a5,
+    0x03a6,
+    0x03a7,
+    0x03a8,
+    0x03a9,
+    0x03aa,
+    0x03ab,
+    0x03ac,
+    0x03ad,
+    0x03ae,
+    0x03af,
+    0x03b0,
+    0x03b1,
+    0x03b2,
+    0x03b3,
+    0x03b4,
+    0x03b5,
+    0x03b6,
+    0x03b7,
+    0x03b8,
+    0x03b9,
+    0x03ba,
+    0x03bb,
+    0x03bc,
+    0x03bd,
+    0x03be,
+    0x03bf,
+    0x03c0,
+    0x03c1,
+    0x03c2,
+    0x03c3,
+    0x03c4,
+    0x03c5,
+    0x03c6,
+    0x03c7,
+    0x03c8,
+    0x03c9,
+    0x03ca,
+    0x03cb,
+    0x03cc,
+    0x03cd,
+    0x03ce,
+    0xfffd,
 );
 
 my @to_utf8 = (
@@ -446,101 +446,101 @@ my @to_utf8 = (
     "\xc2\x9e",
     "\xc2\x9f",
     "\xc2\xa0",
-    "\xc2\xa1",
-    "\xc2\xa2",
+    "\xe2\x80\x98",
+    "\xe2\x80\x99",
     "\xc2\xa3",
-    "\xc2\xa4",
-    "\xc2\xa5",
+    "\xef\xbf\xbd",
+    "\xef\xbf\xbd",
     "\xc2\xa6",
     "\xc2\xa7",
     "\xc2\xa8",
     "\xc2\xa9",
-    "\xc2\xaa",
+    "\xef\xbf\xbd",
     "\xc2\xab",
     "\xc2\xac",
     "\xc2\xad",
-    "\xc2\xae",
-    "\xc2\xaf",
+    "\xef\xbf\xbd",
+    "\xe2\x80\x95",
     "\xc2\xb0",
     "\xc2\xb1",
     "\xc2\xb2",
     "\xc2\xb3",
-    "\xc2\xb4",
-    "\xc2\xb5",
-    "\xc2\xb6",
+    "\xce\x84",
+    "\xce\x85",
+    "\xce\x86",
     "\xc2\xb7",
-    "\xc2\xb8",
-    "\xc2\xb9",
-    "\xc2\xba",
+    "\xce\x88",
+    "\xce\x89",
+    "\xce\x8a",
     "\xc2\xbb",
-    "\xc2\xbc",
+    "\xce\x8c",
     "\xc2\xbd",
-    "\xc2\xbe",
-    "\xc2\xbf",
-    "\xc3\x80",
-    "\xc3\x81",
-    "\xc3\x82",
-    "\xc3\x83",
-    "\xc3\x84",
-    "\xc3\x85",
-    "\xc3\x86",
-    "\xc3\x87",
-    "\xc3\x88",
-    "\xc3\x89",
-    "\xc3\x8a",
-    "\xc3\x8b",
-    "\xc3\x8c",
-    "\xc3\x8d",
-    "\xc3\x8e",
-    "\xc3\x8f",
-    "\xc4\x9e",
-    "\xc3\x91",
-    "\xc3\x92",
-    "\xc3\x93",
-    "\xc3\x94",
-    "\xc3\x95",
-    "\xc3\x96",
-    "\xc3\x97",
-    "\xc3\x98",
-    "\xc3\x99",
-    "\xc3\x9a",
-    "\xc3\x9b",
-    "\xc3\x9c",
-    "\xc4\xb0",
-    "\xc5\x9e",
-    "\xc3\x9f",
-    "\xc3\xa0",
-    "\xc3\xa1",
-    "\xc3\xa2",
-    "\xc3\xa3",
-    "\xc3\xa4",
-    "\xc3\xa5",
-    "\xc3\xa6",
-    "\xc3\xa7",
-    "\xc3\xa8",
-    "\xc3\xa9",
-    "\xc3\xaa",
-    "\xc3\xab",
-    "\xc3\xac",
-    "\xc3\xad",
-    "\xc3\xae",
-    "\xc3\xaf",
-    "\xc4\x9f",
-    "\xc3\xb1",
-    "\xc3\xb2",
-    "\xc3\xb3",
-    "\xc3\xb4",
-    "\xc3\xb5",
-    "\xc3\xb6",
-    "\xc3\xb7",
-    "\xc3\xb8",
-    "\xc3\xb9",
-    "\xc3\xba",
-    "\xc3\xbb",
-    "\xc3\xbc",
-    "\xc4\xb1",
-    "\xc5\x9f",
-    "\xc3\xbf",
+    "\xce\x8e",
+    "\xce\x8f",
+    "\xce\x90",
+    "\xce\x91",
+    "\xce\x92",
+    "\xce\x93",
+    "\xce\x94",
+    "\xce\x95",
+    "\xce\x96",
+    "\xce\x97",
+    "\xce\x98",
+    "\xce\x99",
+    "\xce\x9a",
+    "\xce\x9b",
+    "\xce\x9c",
+    "\xce\x9d",
+    "\xce\x9e",
+    "\xce\x9f",
+    "\xce\xa0",
+    "\xce\xa1",
+    "\xef\xbf\xbd",
+    "\xce\xa3",
+    "\xce\xa4",
+    "\xce\xa5",
+    "\xce\xa6",
+    "\xce\xa7",
+    "\xce\xa8",
+    "\xce\xa9",
+    "\xce\xaa",
+    "\xce\xab",
+    "\xce\xac",
+    "\xce\xad",
+    "\xce\xae",
+    "\xce\xaf",
+    "\xce\xb0",
+    "\xce\xb1",
+    "\xce\xb2",
+    "\xce\xb3",
+    "\xce\xb4",
+    "\xce\xb5",
+    "\xce\xb6",
+    "\xce\xb7",
+    "\xce\xb8",
+    "\xce\xb9",
+    "\xce\xba",
+    "\xce\xbb",
+    "\xce\xbc",
+    "\xce\xbd",
+    "\xce\xbe",
+    "\xce\xbf",
+    "\xcf\x80",
+    "\xcf\x81",
+    "\xcf\x82",
+    "\xcf\x83",
+    "\xcf\x84",
+    "\xcf\x85",
+    "\xcf\x86",
+    "\xcf\x87",
+    "\xcf\x88",
+    "\xcf\x89",
+    "\xcf\x8a",
+    "\xcf\x8b",
+    "\xcf\x8c",
+    "\xcf\x8d",
+    "\xcf\x8e",
+    "\xef\xbf\xbd",
 );
 
 my %from_ucs4 = (
@@ -705,101 +705,95 @@ my %from_ucs4 = (
     0x0000009e => "\x9e",
     0x0000009f => "\x9f",
     0x000000a0 => "\xa0",
-    0x000000a1 => "\xa1",
-    0x000000a2 => "\xa2",
     0x000000a3 => "\xa3",
-    0x000000a4 => "\xa4",
-    0x000000a5 => "\xa5",
     0x000000a6 => "\xa6",
     0x000000a7 => "\xa7",
     0x000000a8 => "\xa8",
     0x000000a9 => "\xa9",
-    0x000000aa => "\xaa",
     0x000000ab => "\xab",
     0x000000ac => "\xac",
     0x000000ad => "\xad",
-    0x000000ae => "\xae",
-    0x000000af => "\xaf",
     0x000000b0 => "\xb0",
     0x000000b1 => "\xb1",
     0x000000b2 => "\xb2",
     0x000000b3 => "\xb3",
-    0x000000b4 => "\xb4",
-    0x000000b5 => "\xb5",
-    0x000000b6 => "\xb6",
     0x000000b7 => "\xb7",
-    0x000000b8 => "\xb8",
-    0x000000b9 => "\xb9",
-    0x000000ba => "\xba",
     0x000000bb => "\xbb",
-    0x000000bc => "\xbc",
     0x000000bd => "\xbd",
-    0x000000be => "\xbe",
-    0x000000bf => "\xbf",
-    0x000000c0 => "\xc0",
-    0x000000c1 => "\xc1",
-    0x000000c2 => "\xc2",
-    0x000000c3 => "\xc3",
-    0x000000c4 => "\xc4",
-    0x000000c5 => "\xc5",
-    0x000000c6 => "\xc6",
-    0x000000c7 => "\xc7",
-    0x000000c8 => "\xc8",
-    0x000000c9 => "\xc9",
-    0x000000ca => "\xca",
-    0x000000cb => "\xcb",
-    0x000000cc => "\xcc",
-    0x000000cd => "\xcd",
-    0x000000ce => "\xce",
-    0x000000cf => "\xcf",
-    0x000000d1 => "\xd1",
-    0x000000d2 => "\xd2",
-    0x000000d3 => "\xd3",
-    0x000000d4 => "\xd4",
-    0x000000d5 => "\xd5",
-    0x000000d6 => "\xd6",
-    0x000000d7 => "\xd7",
-    0x000000d8 => "\xd8",
-    0x000000d9 => "\xd9",
-    0x000000da => "\xda",
-    0x000000db => "\xdb",
-    0x000000dc => "\xdc",
-    0x000000df => "\xdf",
-    0x000000e0 => "\xe0",
-    0x000000e1 => "\xe1",
-    0x000000e2 => "\xe2",
-    0x000000e3 => "\xe3",
-    0x000000e4 => "\xe4",
-    0x000000e5 => "\xe5",
-    0x000000e6 => "\xe6",
-    0x000000e7 => "\xe7",
-    0x000000e8 => "\xe8",
-    0x000000e9 => "\xe9",
-    0x000000ea => "\xea",
-    0x000000eb => "\xeb",
-    0x000000ec => "\xec",
-    0x000000ed => "\xed",
-    0x000000ee => "\xee",
-    0x000000ef => "\xef",
-    0x000000f1 => "\xf1",
-    0x000000f2 => "\xf2",
-    0x000000f3 => "\xf3",
-    0x000000f4 => "\xf4",
-    0x000000f5 => "\xf5",
-    0x000000f6 => "\xf6",
-    0x000000f7 => "\xf7",
-    0x000000f8 => "\xf8",
-    0x000000f9 => "\xf9",
-    0x000000fa => "\xfa",
-    0x000000fb => "\xfb",
-    0x000000fc => "\xfc",
-    0x000000ff => "\xff",
-    0x0000011e => "\xd0",
-    0x0000011f => "\xf0",
-    0x00000130 => "\xdd",
-    0x00000131 => "\xfd",
-    0x0000015e => "\xde",
-    0x0000015f => "\xfe",
+    0x00000384 => "\xb4",
+    0x00000385 => "\xb5",
+    0x00000386 => "\xb6",
+    0x00000388 => "\xb8",
+    0x00000389 => "\xb9",
+    0x0000038a => "\xba",
+    0x0000038c => "\xbc",
+    0x0000038e => "\xbe",
+    0x0000038f => "\xbf",
+    0x00000390 => "\xc0",
+    0x00000391 => "\xc1",
+    0x00000392 => "\xc2",
+    0x00000393 => "\xc3",
+    0x00000394 => "\xc4",
+    0x00000395 => "\xc5",
+    0x00000396 => "\xc6",
+    0x00000397 => "\xc7",
+    0x00000398 => "\xc8",
+    0x00000399 => "\xc9",
+    0x0000039a => "\xca",
+    0x0000039b => "\xcb",
+    0x0000039c => "\xcc",
+    0x0000039d => "\xcd",
+    0x0000039e => "\xce",
+    0x0000039f => "\xcf",
+    0x000003a0 => "\xd0",
+    0x000003a1 => "\xd1",
+    0x000003a3 => "\xd3",
+    0x000003a4 => "\xd4",
+    0x000003a5 => "\xd5",
+    0x000003a6 => "\xd6",
+    0x000003a7 => "\xd7",
+    0x000003a8 => "\xd8",
+    0x000003a9 => "\xd9",
+    0x000003aa => "\xda",
+    0x000003ab => "\xdb",
+    0x000003ac => "\xdc",
+    0x000003ad => "\xdd",
+    0x000003ae => "\xde",
+    0x000003af => "\xdf",
+    0x000003b0 => "\xe0",
+    0x000003b1 => "\xe1",
+    0x000003b2 => "\xe2",
+    0x000003b3 => "\xe3",
+    0x000003b4 => "\xe4",
+    0x000003b5 => "\xe5",
+    0x000003b6 => "\xe6",
+    0x000003b7 => "\xe7",
+    0x000003b8 => "\xe8",
+    0x000003b9 => "\xe9",
+    0x000003ba => "\xea",
+    0x000003bb => "\xeb",
+    0x000003bc => "\xec",
+    0x000003bd => "\xed",
+    0x000003be => "\xee",
+    0x000003bf => "\xef",
+    0x000003c0 => "\xf0",
+    0x000003c1 => "\xf1",
+    0x000003c2 => "\xf2",
+    0x000003c3 => "\xf3",
+    0x000003c4 => "\xf4",
+    0x000003c5 => "\xf5",
+    0x000003c6 => "\xf6",
+    0x000003c7 => "\xf7",
+    0x000003c8 => "\xf8",
+    0x000003c9 => "\xf9",
+    0x000003ca => "\xfa",
+    0x000003cb => "\xfb",
+    0x000003cc => "\xfc",
+    0x000003cd => "\xfd",
+    0x000003ce => "\xfe",
+    0x00002015 => "\xaf",
+    0x00002018 => "\xa1",
+    0x00002019 => "\xa2",
 );
 
 sub _recode
@@ -827,7 +821,7 @@ __END__
 
 =head1 NAME
 
-Locale::RecodeData::ISO_8859_9 - Conversion routines for ISO-8859-9
+Locale::RecodeData::ISO_8859_7 - Conversion routines for ISO-8859-7
 
 =head1 SYNOPSIS
 
@@ -836,7 +830,7 @@ This module is internal to libintl.  Do not use directly!
 =head1 DESCRIPTION
 
 This module is generated and contains the conversion tables and
-routines for ISO-8859-9.
+routines for ISO-8859-7.
 
 =head1 COMMENTS
 
@@ -844,11 +838,13 @@ The following comments have been extracted from the original charmap:
 
  version: 1.0
   source: ECMA registry
- alias ISO-IR-148
- alias ISO_8859-9:1989
- alias ISO_8859-9
- alias LATIN5
- alias L5
+ alias ISO-IR-126
+ alias ISO_8859-7:1987
+ alias ISO_8859-7
+ alias ELOT_928
+ alias ECMA-118
+ alias GREEK
+ alias GREEK8
 
 Please note that aliases listed above are not necessarily valid!
 
@@ -1021,101 +1017,95 @@ All character codes are in hexadecimal.  Please read 'ISO-10646' as
     9E |  0000009E | PRIVACY MESSAGE (PM)
     9F |  0000009F | APPLICATION PROGRAM COMMAND (APC)
     A0 |  000000A0 | NO-BREAK SPACE
-    A1 |  000000A1 | INVERTED EXCLAMATION MARK
-    A2 |  000000A2 | CENT SIGN
+    A1 |  00002018 | LEFT SINGLE QUOTATION MARK
+    A2 |  00002019 | RIGHT SINGLE QUOTATION MARK
     A3 |  000000A3 | POUND SIGN
-    A4 |  000000A4 | CURRENCY SIGN
-    A5 |  000000A5 | YEN SIGN
     A6 |  000000A6 | BROKEN BAR
     A7 |  000000A7 | SECTION SIGN
     A8 |  000000A8 | DIAERESIS
     A9 |  000000A9 | COPYRIGHT SIGN
-    AA |  000000AA | FEMININE ORDINAL INDICATOR
     AB |  000000AB | LEFT-POINTING DOUBLE ANGLE QUOTATION MARK
     AC |  000000AC | NOT SIGN
     AD |  000000AD | SOFT HYPHEN
-    AE |  000000AE | REGISTERED SIGN
-    AF |  000000AF | MACRON
+    AF |  00002015 | HORIZONTAL BAR
     B0 |  000000B0 | DEGREE SIGN
     B1 |  000000B1 | PLUS-MINUS SIGN
     B2 |  000000B2 | SUPERSCRIPT TWO
     B3 |  000000B3 | SUPERSCRIPT THREE
-    B4 |  000000B4 | ACUTE ACCENT
-    B5 |  000000B5 | MICRO SIGN
-    B6 |  000000B6 | PILCROW SIGN
+    B4 |  00000384 | GREEK TONOS
+    B5 |  00000385 | GREEK DIALYTIKA TONOS
+    B6 |  00000386 | GREEK CAPITAL LETTER ALPHA WITH TONOS
     B7 |  000000B7 | MIDDLE DOT
-    B8 |  000000B8 | CEDILLA
-    B9 |  000000B9 | SUPERSCRIPT ONE
-    BA |  000000BA | MASCULINE ORDINAL INDICATOR
+    B8 |  00000388 | GREEK CAPITAL LETTER EPSILON WITH TONOS
+    B9 |  00000389 | GREEK CAPITAL LETTER ETA WITH TONOS
+    BA |  0000038A | GREEK CAPITAL LETTER IOTA WITH TONOS
     BB |  000000BB | RIGHT-POINTING DOUBLE ANGLE QUOTATION MARK
-    BC |  000000BC | VULGAR FRACTION ONE QUARTER
+    BC |  0000038C | GREEK CAPITAL LETTER OMICRON WITH TONOS
     BD |  000000BD | VULGAR FRACTION ONE HALF
-    BE |  000000BE | VULGAR FRACTION THREE QUARTERS
-    BF |  000000BF | INVERTED QUESTION MARK
-    C0 |  000000C0 | LATIN CAPITAL LETTER A WITH GRAVE
-    C1 |  000000C1 | LATIN CAPITAL LETTER A WITH ACUTE
-    C2 |  000000C2 | LATIN CAPITAL LETTER A WITH CIRCUMFLEX
-    C3 |  000000C3 | LATIN CAPITAL LETTER A WITH TILDE
-    C4 |  000000C4 | LATIN CAPITAL LETTER A WITH DIAERESIS
-    C5 |  000000C5 | LATIN CAPITAL LETTER A WITH RING ABOVE
-    C6 |  000000C6 | LATIN CAPITAL LETTER AE
-    C7 |  000000C7 | LATIN CAPITAL LETTER C WITH CEDILLA
-    C8 |  000000C8 | LATIN CAPITAL LETTER E WITH GRAVE
-    C9 |  000000C9 | LATIN CAPITAL LETTER E WITH ACUTE
-    CA |  000000CA | LATIN CAPITAL LETTER E WITH CIRCUMFLEX
-    CB |  000000CB | LATIN CAPITAL LETTER E WITH DIAERESIS
-    CC |  000000CC | LATIN CAPITAL LETTER I WITH GRAVE
-    CD |  000000CD | LATIN CAPITAL LETTER I WITH ACUTE
-    CE |  000000CE | LATIN CAPITAL LETTER I WITH CIRCUMFLEX
-    CF |  000000CF | LATIN CAPITAL LETTER I WITH DIAERESIS
-    D0 |  0000011E | LATIN CAPITAL LETTER G WITH BREVE
-    D1 |  000000D1 | LATIN CAPITAL LETTER N WITH TILDE
-    D2 |  000000D2 | LATIN CAPITAL LETTER O WITH GRAVE
-    D3 |  000000D3 | LATIN CAPITAL LETTER O WITH ACUTE
-    D4 |  000000D4 | LATIN CAPITAL LETTER O WITH CIRCUMFLEX
-    D5 |  000000D5 | LATIN CAPITAL LETTER O WITH TILDE
-    D6 |  000000D6 | LATIN CAPITAL LETTER O WITH DIAERESIS
-    D7 |  000000D7 | MULTIPLICATION SIGN
-    D8 |  000000D8 | LATIN CAPITAL LETTER O WITH STROKE
-    D9 |  000000D9 | LATIN CAPITAL LETTER U WITH GRAVE
-    DA |  000000DA | LATIN CAPITAL LETTER U WITH ACUTE
-    DB |  000000DB | LATIN CAPITAL LETTER U WITH CIRCUMFLEX
-    DC |  000000DC | LATIN CAPITAL LETTER U WITH DIAERESIS
-    DD |  00000130 | LATIN CAPITAL LETTER I WITH DOT ABOVE
-    DE |  0000015E | LATIN CAPITAL LETTER S WITH CEDILLA
-    DF |  000000DF | LATIN SMALL LETTER SHARP S (German)
-    E0 |  000000E0 | LATIN SMALL LETTER A WITH GRAVE
-    E1 |  000000E1 | LATIN SMALL LETTER A WITH ACUTE
-    E2 |  000000E2 | LATIN SMALL LETTER A WITH CIRCUMFLEX
-    E3 |  000000E3 | LATIN SMALL LETTER A WITH TILDE
-    E4 |  000000E4 | LATIN SMALL LETTER A WITH DIAERESIS
-    E5 |  000000E5 | LATIN SMALL LETTER A WITH RING ABOVE
-    E6 |  000000E6 | LATIN SMALL LETTER AE
-    E7 |  000000E7 | LATIN SMALL LETTER C WITH CEDILLA
-    E8 |  000000E8 | LATIN SMALL LETTER E WITH GRAVE
-    E9 |  000000E9 | LATIN SMALL LETTER E WITH ACUTE
-    EA |  000000EA | LATIN SMALL LETTER E WITH CIRCUMFLEX
-    EB |  000000EB | LATIN SMALL LETTER E WITH DIAERESIS
-    EC |  000000EC | LATIN SMALL LETTER I WITH GRAVE
-    ED |  000000ED | LATIN SMALL LETTER I WITH ACUTE
-    EE |  000000EE | LATIN SMALL LETTER I WITH CIRCUMFLEX
-    EF |  000000EF | LATIN SMALL LETTER I WITH DIAERESIS
-    F0 |  0000011F | LATIN SMALL LETTER G WITH BREVE
-    F1 |  000000F1 | LATIN SMALL LETTER N WITH TILDE
-    F2 |  000000F2 | LATIN SMALL LETTER O WITH GRAVE
-    F3 |  000000F3 | LATIN SMALL LETTER O WITH ACUTE
-    F4 |  000000F4 | LATIN SMALL LETTER O WITH CIRCUMFLEX
-    F5 |  000000F5 | LATIN SMALL LETTER O WITH TILDE
-    F6 |  000000F6 | LATIN SMALL LETTER O WITH DIAERESIS
-    F7 |  000000F7 | DIVISION SIGN
-    F8 |  000000F8 | LATIN SMALL LETTER O WITH STROKE
-    F9 |  000000F9 | LATIN SMALL LETTER U WITH GRAVE
-    FA |  000000FA | LATIN SMALL LETTER U WITH ACUTE
-    FB |  000000FB | LATIN SMALL LETTER U WITH CIRCUMFLEX
-    FC |  000000FC | LATIN SMALL LETTER U WITH DIAERESIS
-    FD |  00000131 | LATIN SMALL LETTER DOTLESS I
-    FE |  0000015F | LATIN SMALL LETTER S WITH CEDILLA
-    FF |  000000FF | LATIN SMALL LETTER Y WITH DIAERESIS
+    BE |  0000038E | GREEK CAPITAL LETTER UPSILON WITH TONOS
+    BF |  0000038F | GREEK CAPITAL LETTER OMEGA WITH TONOS
+    C0 |  00000390 | GREEK SMALL LETTER IOTA WITH DIALYTIKA AND TONOS
+    C1 |  00000391 | GREEK CAPITAL LETTER ALPHA
+    C2 |  00000392 | GREEK CAPITAL LETTER BETA
+    C3 |  00000393 | GREEK CAPITAL LETTER GAMMA
+    C4 |  00000394 | GREEK CAPITAL LETTER DELTA
+    C5 |  00000395 | GREEK CAPITAL LETTER EPSILON
+    C6 |  00000396 | GREEK CAPITAL LETTER ZETA
+    C7 |  00000397 | GREEK CAPITAL LETTER ETA
+    C8 |  00000398 | GREEK CAPITAL LETTER THETA
+    C9 |  00000399 | GREEK CAPITAL LETTER IOTA
+    CA |  0000039A | GREEK CAPITAL LETTER KAPPA
+    CB |  0000039B | GREEK CAPITAL LETTER LAMDA
+    CC |  0000039C | GREEK CAPITAL LETTER MU
+    CD |  0000039D | GREEK CAPITAL LETTER NU
+    CE |  0000039E | GREEK CAPITAL LETTER XI
+    CF |  0000039F | GREEK CAPITAL LETTER OMICRON
+    D0 |  000003A0 | GREEK CAPITAL LETTER PI
+    D1 |  000003A1 | GREEK CAPITAL LETTER RHO
+    D3 |  000003A3 | GREEK CAPITAL LETTER SIGMA
+    D4 |  000003A4 | GREEK CAPITAL LETTER TAU
+    D5 |  000003A5 | GREEK CAPITAL LETTER UPSILON
+    D6 |  000003A6 | GREEK CAPITAL LETTER PHI
+    D7 |  000003A7 | GREEK CAPITAL LETTER CHI
+    D8 |  000003A8 | GREEK CAPITAL LETTER PSI
+    D9 |  000003A9 | GREEK CAPITAL LETTER OMEGA
+    DA |  000003AA | GREEK CAPITAL LETTER IOTA WITH DIALYTIKA
+    DB |  000003AB | GREEK CAPITAL LETTER UPSILON WITH DIALYTIKA
+    DC |  000003AC | GREEK SMALL LETTER ALPHA WITH TONOS
+    DD |  000003AD | GREEK SMALL LETTER EPSILON WITH TONOS
+    DE |  000003AE | GREEK SMALL LETTER ETA WITH TONOS
+    DF |  000003AF | GREEK SMALL LETTER IOTA WITH TONOS
+    E0 |  000003B0 | GREEK SMALL LETTER UPSILON WITH DIALYTIKA AND TONOS
+    E1 |  000003B1 | GREEK SMALL LETTER ALPHA
+    E2 |  000003B2 | GREEK SMALL LETTER BETA
+    E3 |  000003B3 | GREEK SMALL LETTER GAMMA
+    E4 |  000003B4 | GREEK SMALL LETTER DELTA
+    E5 |  000003B5 | GREEK SMALL LETTER EPSILON
+    E6 |  000003B6 | GREEK SMALL LETTER ZETA
+    E7 |  000003B7 | GREEK SMALL LETTER ETA
+    E8 |  000003B8 | GREEK SMALL LETTER THETA
+    E9 |  000003B9 | GREEK SMALL LETTER IOTA
+    EA |  000003BA | GREEK SMALL LETTER KAPPA
+    EB |  000003BB | GREEK SMALL LETTER LAMDA
+    EC |  000003BC | GREEK SMALL LETTER MU
+    ED |  000003BD | GREEK SMALL LETTER NU
+    EE |  000003BE | GREEK SMALL LETTER XI
+    EF |  000003BF | GREEK SMALL LETTER OMICRON
+    F0 |  000003C0 | GREEK SMALL LETTER PI
+    F1 |  000003C1 | GREEK SMALL LETTER RHO
+    F2 |  000003C2 | GREEK SMALL LETTER FINAL SIGMA
+    F3 |  000003C3 | GREEK SMALL LETTER SIGMA
+    F4 |  000003C4 | GREEK SMALL LETTER TAU
+    F5 |  000003C5 | GREEK SMALL LETTER UPSILON
+    F6 |  000003C6 | GREEK SMALL LETTER PHI
+    F7 |  000003C7 | GREEK SMALL LETTER CHI
+    F8 |  000003C8 | GREEK SMALL LETTER PSI
+    F9 |  000003C9 | GREEK SMALL LETTER OMEGA
+    FA |  000003CA | GREEK SMALL LETTER IOTA WITH DIALYTIKA
+    FB |  000003CB | GREEK SMALL LETTER UPSILON WITH DIALYTIKA
+    FC |  000003CC | GREEK SMALL LETTER OMICRON WITH TONOS
+    FD |  000003CD | GREEK SMALL LETTER UPSILON WITH TONOS
+    FE |  000003CE | GREEK SMALL LETTER OMEGA WITH TONOS
 
 
 =head1 AUTHOR
