@@ -3,7 +3,7 @@
 # vim: set autoindent shiftwidth=4 tabstop=4:
 
 # Conversion routines for UTF-8 (perl < 5.8.0).
-# Copyright (C) 2002-2015 Guido Flohr <guido.flohr@cantanea.com>,
+# Copyright (C) 2002-2016 Guido Flohr <guido.flohr@cantanea.com>,
 # all rights reserved.
 
 # This program is free software: you can redistribute it and/or modify
@@ -166,8 +166,9 @@ See http://www.unicode.org/.
 
 =head1 AUTHOR
 
-Copyright (C) 2002-2015, Guido Flohr E<lt>guido.flohr@cantanea.comE<gt>, all
-rights reserved.  See the source code for details.
+Copyright (C) 2002-2016 L<Guido Flohr|http://www.guido-flohr.net/>
+(L<mailto:guido.flohr@cantanea.com>), all rights reserved.  See the source
+code for details!code for details!
 
 =head1 SEE ALSO
 
